@@ -54,6 +54,7 @@
 #include "Options.h"
 #include "widgets/kshelplabel.h"
 #include "addlinkdialog.h"
+#include "observinglist.h"
 
 #include <config-kstars.h>
 
@@ -500,7 +501,7 @@ void DetailDialog::createPositionTab( const KStarsDateTime &ut, GeoLocation *geo
     //equivalent to 1./sin(Alt).  Beware of Inf at Alt=0!
     if ( selectedObject->alt().Degrees() > 0.0 )
         Pos->Airmass->setText( QLocale().toString(
-                                   1./sin( selectedObject->alt().radians() ), 'f', 2 ) );
+                                                  selectedObject->airmass() , 'f', 2 ) );
     else
         Pos->Airmass->setText( "--" );
 
