@@ -72,6 +72,7 @@ EkosManager::EkosManager()
     dome    =  NULL;
     weather =  NULL;
     dustCap =  NULL;
+    lightBox= NULL;
 
     scope_di   = NULL;
     ccd_di     = NULL;
@@ -148,7 +149,7 @@ EkosManager::EkosManager()
     // Temporary fix. Not sure how to resize Ekos Dialog to fit contents of the various tabs in the QScrollArea which are added
     // dynamically. I used setMinimumSize() but it doesn't appear to make any difference.
     // Also set Layout policy to SetMinAndMaxSize as well. Any idea how to fix this?
-    resize(1000,800);
+    resize(900,750);
 }
 
 EkosManager::~EkosManager()
@@ -242,8 +243,6 @@ void EkosManager::processINDIModeChange()
 
 void EkosManager::initLocalDrivers()
 {
-    int i=0;
-
     telescopeCombo->clear();
     ccdCombo->clear();
     guiderCombo->clear();
@@ -325,31 +324,21 @@ void EkosManager::initLocalDrivers()
         {
         case KSTARS_TELESCOPE:
         {
-            for (i=0; i < telescopeCombo->count(); i++)
-                if (telescopeCombo->itemText(i) == dv->getTreeLabel())
-                    break;
-            if (i == telescopeCombo->count())
+            if (telescopeCombo->findText(dv->getTreeLabel()) == -1)
                 telescopeCombo->addItem(dv->getTreeLabel());
         }
         break;
 
         case KSTARS_CCD:
         {
-            for (i=0; i < ccdCombo->count(); i++)
-                if (ccdCombo->itemText(i) == dv->getTreeLabel())
-                    break;
-
-            if (i == ccdCombo->count())
-            {
+            if (ccdCombo->findText(dv->getTreeLabel()) == -1)
                 ccdCombo->addItem(dv->getTreeLabel());
+
+            if (guiderCombo->findText(dv->getTreeLabel()) == -1)
                 guiderCombo->addItem(dv->getTreeLabel());
-            }
 
             // Also add CCD drivers to AUX list
-            for (i=0; i < aux1Combo->count(); i++)
-                if (aux1Combo->itemText(i) == dv->getTreeLabel())
-                    break;
-            if (i == aux1Combo->count())
+            if (aux1Combo->findText(dv->getTreeLabel()) == -1)
             {
                 aux1Combo->addItem(dv->getTreeLabel());
                 aux2Combo->addItem(dv->getTreeLabel());
@@ -362,60 +351,42 @@ void EkosManager::initLocalDrivers()
 
         case KSTARS_ADAPTIVE_OPTICS:
         {
-            for (i=0; i < AOCombo->count(); i++)
-                if (AOCombo->itemText(i) == dv->getTreeLabel())
-                    break;
-            if (i == AOCombo->count())
+            if (AOCombo->findText(dv->getTreeLabel()) == -1)
                 AOCombo->addItem(dv->getTreeLabel());
         }
         break;
 
         case KSTARS_FOCUSER:
         {
-            for (i=0; i < focuserCombo->count(); i++)
-                if (focuserCombo->itemText(i) == dv->getTreeLabel())
-                    break;
-            if (i == focuserCombo->count())
+            if (focuserCombo->findText(dv->getTreeLabel()) == -1)
                 focuserCombo->addItem(dv->getTreeLabel());
         }
             break;
 
         case KSTARS_FILTER:
         {
-            for (i=0; i < filterCombo->count(); i++)
-                if (filterCombo->itemText(i) == dv->getTreeLabel())
-                    break;
-            if (i == filterCombo->count())
+            if (filterCombo->findText(dv->getTreeLabel()) == -1)
                 filterCombo->addItem(dv->getTreeLabel());
         }
         break;
 
         case KSTARS_DOME:
         {
-            for (i=0; i < domeCombo->count(); i++)
-                if (domeCombo->itemText(i) == dv->getTreeLabel())
-                    break;
-            if (i == domeCombo->count())
+            if (domeCombo->findText(dv->getTreeLabel()) == -1)
                 domeCombo->addItem(dv->getTreeLabel());
         }
         break;
 
         case KSTARS_WEATHER:
         {
-            for (i=0; i < weatherCombo->count(); i++)
-                if (weatherCombo->itemText(i) == dv->getTreeLabel())
-                    break;
-            if (i == weatherCombo->count())
+            if (weatherCombo->findText(dv->getTreeLabel()) == -1)
                 weatherCombo->addItem(dv->getTreeLabel());
         }
         break;
 
         case KSTARS_AUXILIARY:
         {
-            for (i=0; i < aux1Combo->count(); i++)
-                if (aux1Combo->itemText(i) == dv->getTreeLabel())
-                    break;
-            if (i == aux1Combo->count())
+            if (aux1Combo->findText(dv->getTreeLabel()) == -1)
             {
                 aux1Combo->addItem(dv->getTreeLabel());
                 aux2Combo->addItem(dv->getTreeLabel());
@@ -501,8 +472,6 @@ void EkosManager::saveLocalDrivers()
 
 void EkosManager::initRemoteDrivers()
 {
-    int i=0;
-
     telescopeCombo->clear();
     ccdCombo->clear();
     guiderCombo->clear();
@@ -555,10 +524,10 @@ void EkosManager::initRemoteDrivers()
         AOCombo->addItem(remoteAOName);
 
     if (remoteFilterName.isEmpty() == false)
-        focuserCombo->addItem(remoteFilterName);
+        filterCombo->addItem(remoteFilterName);
 
     if (remoteFocuserName.isEmpty() == false)
-        filterCombo->addItem(remoteFocuserName);
+        focuserCombo->addItem(remoteFocuserName);
 
     if (remoteDomeName.isEmpty() == false)
         domeCombo->addItem(remoteDomeName);
@@ -584,30 +553,21 @@ void EkosManager::initRemoteDrivers()
         {
         case KSTARS_TELESCOPE:
         {
-            for (i=0; i < telescopeCombo->count(); i++)
-                if (telescopeCombo->itemText(i) == dv->getName())
-                    break;
-            if (i == telescopeCombo->count())
+            if (telescopeCombo->findText(dv->getName()) == -1)
                 telescopeCombo->addItem(dv->getName());
         }
-             break;
+        break;
 
         case KSTARS_CCD:
         {
-            for (i=0; i < ccdCombo->count(); i++)
-                if (ccdCombo->itemText(i) == dv->getName())
-                    break;
-
-            if (i == ccdCombo->count())
-            {
+            if (ccdCombo->findText(dv->getName()) == -1)
                 ccdCombo->addItem(dv->getName());
-                guiderCombo->addItem(dv->getName());
-            }
 
-            for (i=0; i < aux1Combo->count(); i++)
-                if (aux1Combo->itemText(i) == dv->getName())
-                    break;
-            if (i == aux1Combo->count())
+            if (guiderCombo->findText(dv->getName()) == -1)
+                guiderCombo->addItem(dv->getName());
+
+            // Also add CCD drivers to AUX list
+            if (aux1Combo->findText(dv->getName()) == -1)
             {
                 aux1Combo->addItem(dv->getName());
                 aux2Combo->addItem(dv->getName());
@@ -620,60 +580,42 @@ void EkosManager::initRemoteDrivers()
 
         case KSTARS_ADAPTIVE_OPTICS:
         {
-            for (i=0; i < AOCombo->count(); i++)
-                if (AOCombo->itemText(i) == dv->getName())
-                    break;
-            if (i == AOCombo->count())
+            if (AOCombo->findText(dv->getName()) == -1)
                 AOCombo->addItem(dv->getName());
         }
         break;
 
         case KSTARS_FOCUSER:
         {
-            for (i=0; i < focuserCombo->count(); i++)
-                if (focuserCombo->itemText(i) == dv->getName())
-                    break;
-            if (i == focuserCombo->count())
+            if (focuserCombo->findText(dv->getName()) == -1)
                 focuserCombo->addItem(dv->getName());
         }
             break;
 
         case KSTARS_FILTER:
         {
-            for (i=0; i < filterCombo->count(); i++)
-                if (filterCombo->itemText(i) == dv->getName())
-                    break;
-            if (i == filterCombo->count())
+            if (filterCombo->findText(dv->getName()) == -1)
                 filterCombo->addItem(dv->getName());
         }
         break;
 
         case KSTARS_DOME:
         {
-            for (i=0; i < domeCombo->count(); i++)
-                if (domeCombo->itemText(i) == dv->getName())
-                    break;
-            if (i == domeCombo->count())
+            if (domeCombo->findText(dv->getName()) == -1)
                 domeCombo->addItem(dv->getName());
         }
         break;
 
         case KSTARS_WEATHER:
         {
-            for (i=0; i < weatherCombo->count(); i++)
-                if (weatherCombo->itemText(i) == dv->getName())
-                    break;
-            if (i == weatherCombo->count())
+            if (weatherCombo->findText(dv->getName()) == -1)
                 weatherCombo->addItem(dv->getName());
         }
         break;
 
         case KSTARS_AUXILIARY:
         {
-            for (i=0; i < aux1Combo->count(); i++)
-                if (aux1Combo->itemText(i) == dv->getName())
-                    break;
-            if (i == aux1Combo->count())
+            if (aux1Combo->findText(dv->getName()) == -1)
             {
                 aux1Combo->addItem(dv->getName());
                 aux2Combo->addItem(dv->getName());
@@ -686,7 +628,6 @@ void EkosManager::initRemoteDrivers()
         default:
             continue;
             break;
-
         }
     }
 
@@ -918,7 +859,7 @@ bool EkosManager::start()
             // For #1, we modify guider_di to make a unique label for the other device with postfix "Guide"
             // For #2, we set guider_di to NULL and we prompt the user to select which device is primary ccd and which is guider
             // since this is the only way to find out in real time.
-            if (guider_di->getDriver() == ccd_di->getDriver())
+            if (ccd_di && guider_di->getDriver() == ccd_di->getDriver())
             {
                 if (guider_di->getAuxInfo().value("mdpd", false).toBool() == true)
                     guider_di = NULL;
@@ -1059,6 +1000,7 @@ bool EkosManager::start()
     connect(INDIListener::Instance(), SIGNAL(newDome(ISD::GDInterface*)), this, SLOT(setDome(ISD::GDInterface*)));
     connect(INDIListener::Instance(), SIGNAL(newWeather(ISD::GDInterface*)), this, SLOT(setWeather(ISD::GDInterface*)));
     connect(INDIListener::Instance(), SIGNAL(newDustCap(ISD::GDInterface*)), this, SLOT(setDustCap(ISD::GDInterface*)));
+    connect(INDIListener::Instance(), SIGNAL(newLightBox(ISD::GDInterface*)), this, SLOT(setLightBox(ISD::GDInterface*)));
     connect(INDIListener::Instance(), SIGNAL(newST4(ISD::ST4*)), this, SLOT(setST4(ISD::ST4*)));
     connect(INDIListener::Instance(), SIGNAL(deviceRemoved(ISD::GDInterface*)), this, SLOT(removeDevice(ISD::GDInterface*)), Qt::DirectConnection);
     connect(DriverManager::Instance(), SIGNAL(serverTerminated(QString,QString)), this, SLOT(cleanDevices()));
@@ -1634,6 +1576,14 @@ void EkosManager::deviceConnected()
 
     nConnectedDevices++;
 
+    if (Options::verboseLogging())
+    {
+        ISD::GDInterface *device = (ISD::GDInterface *) sender();
+        qDebug() << device->getDeviceName() << " is connected.";
+        qDebug() << "Managed Devices: " << managedDevices.count() << " Remote Devices: " << nRemoteDevices;
+        qDebug() << "Connected Devices: " << nConnectedDevices << " nDevices: " << nDevices;
+    }
+
     if (nConnectedDevices == managedDevices.count() || (nDevices <=0 && nConnectedDevices == nRemoteDevices))
         indiConnectionStatus = STATUS_SUCCESS;
 
@@ -1738,13 +1688,22 @@ void EkosManager::deviceDisconnected()
     {
         if (dev->getState("CONNECTION") == IPS_ALERT)
             indiConnectionStatus = STATUS_ERROR;
+        else if (dev->getState("CONNECTION") == IPS_BUSY)
+            indiConnectionStatus = STATUS_PENDING;
         else
             indiConnectionStatus = STATUS_IDLE;
     }
     else
         indiConnectionStatus = STATUS_IDLE;
 
-    nConnectedDevices--;
+    if (Options::verboseLogging())
+    {
+        qDebug() << dev->getDeviceName() << " is disconnected.";
+        qDebug() << "Connected Devices: " << nConnectedDevices << " nDevices: " << nDevices;
+    }
+
+    if (indiConnectionStatus == STATUS_IDLE)
+        nConnectedDevices--;
 
     if (nConnectedDevices < 0)
         nConnectedDevices = 0;
@@ -1816,6 +1775,7 @@ void EkosManager::setCCD(ISD::GDInterface *ccdDevice)
       alignProcess->setTelescope(scope);
       captureProcess->setTelescope(scope);
    }
+
 }
 
 /*void EkosManager::setCCD(ISD::GDInterface *ccdDevice)
@@ -1952,6 +1912,17 @@ void EkosManager::setDustCap(ISD::GDInterface *dustCapDevice)
     dustCapProcess->setDustCap(dustCap);
 
     appendLogText(i18n("%1 is online.", dustCap->getDeviceName()));
+
+    if (captureProcess)
+        captureProcess->setDustCap(dustCap);
+}
+
+void EkosManager::setLightBox(ISD::GDInterface *lightBoxDevice)
+{
+    lightBox = lightBoxDevice;
+
+    if (captureProcess)
+        captureProcess->setLightBox(lightBoxDevice);
 }
 
 void EkosManager::removeDevice(ISD::GDInterface* devInterface)
@@ -2240,6 +2211,11 @@ void EkosManager::initCapture()
      toolsWidget->tabBar()->setTabToolTip(index, i18nc("Charge-Coupled Device", "CCD"));
      connect(captureProcess, SIGNAL(newLog()), this, SLOT(updateLog()));
 
+     if (dustCap)
+         captureProcess->setDustCap(dustCap);
+     if (lightBox)
+         captureProcess->setLightBox(lightBox);
+
      if (focusProcess)
      {
          // Autofocus
@@ -2392,7 +2368,7 @@ void EkosManager::initGuide()
         connect(captureProcess, SIGNAL(exposureComplete()), guideProcess, SLOT(dither()));
 
         // Parking
-        connect(captureProcess, SIGNAL(telescopeParking()), guideProcess, SLOT(stopGuiding()));
+        connect(captureProcess, SIGNAL(mountParking()), guideProcess, SLOT(stopGuiding()));
 
         // Guide Head
         connect(captureProcess, SIGNAL(suspendGuiding(bool)), guideProcess, SLOT(setSuspended(bool)));
@@ -2490,6 +2466,8 @@ void EkosManager::removeTabs()
         delete (dustCapProcess);
         dustCapProcess = NULL;
 
+        lightBox = NULL;
+
         aux1 = NULL;
         aux2 = NULL;
         aux3 = NULL;
