@@ -27,7 +27,6 @@
 
 #include <QDialog>
 #include <QHash>
-#include <QtMultimedia/QMediaPlayer>
 #include <QtDBus/QtDBus>
 
 class DriverInfo;
@@ -67,6 +66,12 @@ public:
     void setOptionsWidget(KPageWidgetItem *ops) { ekosOption = ops; }
     void addObjectToScheduler(SkyObject *object);
 
+    Ekos::Capture *captureModule() { return captureProcess;}
+    Ekos::Focus *focusModule() { return focusProcess;}
+    Ekos::Guide *guideModule() { return guideProcess;}
+    Ekos::Align *alignModule() { return alignProcess;}
+    Ekos::Mount *mountModule() { return mountProcess;}
+
     /** @defgroup EkosDBusInterface Ekos DBus Interface
      * EkosManager interface provides advanced scripting capabilities to establish and shutdown Ekos services.
     */
@@ -185,12 +190,6 @@ public slots:
     void processNewNumber(INumberVectorProperty *nvp);
     void processNewText(ITextVectorProperty *tvp);
 
-    Ekos::Capture *captureModule() { return captureProcess;}
-    Ekos::Focus *focusModule() { return focusProcess;}
-    Ekos::Guide *guideModule() { return guideProcess;}
-    Ekos::Align *alignModule() { return alignProcess;}
-    Ekos::Mount *mountModule() { return mountProcess;}
-
 protected slots:
 
     void updateLog();
@@ -217,6 +216,7 @@ protected slots:
     void setDome(ISD::GDInterface *);
     void setWeather(ISD::GDInterface *);
     void setDustCap(ISD::GDInterface *);
+    void setLightBox(ISD::GDInterface *);
     void setST4(ISD::ST4 *);    
 
  private:
@@ -250,7 +250,7 @@ protected slots:
     bool remoteCCDRegistered;
     bool remoteGuideRegistered;
 
-    ISD::GDInterface *scope, *ccd, *guider, *focuser, *filter, *aux1, *aux2, *aux3, *aux4, *dome, *ao, *weather, *dustCap;
+    ISD::GDInterface *scope, *ccd, *guider, *focuser, *filter, *aux1, *aux2, *aux3, *aux4, *dome, *ao, *weather, *dustCap, *lightBox;
     DriverInfo *scope_di, *ccd_di, *guider_di, *filter_di, *focuser_di, *aux1_di, *aux2_di, *aux3_di,*aux4_di, *ao_di, *dome_di, *weather_di, *remote_indi;
 
     Ekos::Capture *captureProcess;
@@ -268,7 +268,7 @@ protected slots:
     bool localMode, ccdDriverSelected;
 
     int nDevices, nRemoteDevices;
-    int nConnectedDevices;
+    QAtomicInt nConnectedDevices;
     QList<DriverInfo *> managedDevices;
     QHash<QString, DriverInfo *> driversList;
     QStringList logText;
