@@ -779,7 +779,7 @@ CCD::CCD(GDInterface *iPtr) : DeviceDecorator(iPtr)
     fv          = NULL;
     streamWindow      = NULL;
     ST4Driver = NULL;
-    seqCount  = 0 ;
+    nextSequenceID  = 0 ;
 
     primaryChip = new CCDChip(baseDevice, clientManager, CCDChip::PRIMARY_CCD);
 
@@ -1105,19 +1105,17 @@ void CCD::processBLOB(IBLOB* bp)
     QTemporaryFile tmpFile(QDir::tempPath() + "/fitsXXXXXX");
 
     if (currentDir.endsWith('/'))
-        currentDir.truncate(sizeof(currentDir)-1);
+        currentDir.truncate(sizeof(currentDir)-1);    
 
     if (QDir(currentDir).exists() == false)
-    {
-        KMessageBox::error(0, i18n("FITS directory %1 does not exist. Please update the directory in the options.", currentDir));
-        emit BLOBUpdated(NULL);
-        return;
-    }
+        QDir().mkpath(currentDir);
 
     QString filename(currentDir + '/');
 
-    // Create file name for FITS to be shown in FITS Viewer
-    if (Options::showFITS() && (targetChip->isBatchMode() == false || targetChip->getCaptureMode() != FITS_NORMAL))
+    // Create temporary name if ANY of the following conditions are met:
+    // 1. file is preview or batch mode is not enabled
+    // 2. file type is not FITS_NORMAL (focus, guide..etc)
+    if (targetChip->isBatchMode() == false || targetChip->getCaptureMode() != FITS_NORMAL)
     {
 
         //tmpFile.setPrefix("fits");
@@ -1146,9 +1144,9 @@ void CCD::processBLOB(IBLOB* bp)
          QString ts = QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss");
 
          if (ISOMode == false)
-               filename += seqPrefix + (seqPrefix.isEmpty() ? "" : "_") +  QString("%1.%2").arg(QString().sprintf("%03d", seqCount)).arg(QString(fmt));
+               filename += seqPrefix + (seqPrefix.isEmpty() ? "" : "_") +  QString("%1.%2").arg(QString().sprintf("%03d", nextSequenceID)).arg(QString(fmt));
           else
-               filename += seqPrefix + (seqPrefix.isEmpty() ? "" : "_") + QString("%1_%2.%3").arg(QString().sprintf("%03d", seqCount)).arg(ts).arg(QString(fmt));
+               filename += seqPrefix + (seqPrefix.isEmpty() ? "" : "_") + QString("%1_%2.%3").arg(QString().sprintf("%03d", nextSequenceID)).arg(ts).arg(QString(fmt));
 
             QFile fits_temp_file(filename);
             if (!fits_temp_file.open(QIODevice::WriteOnly))
@@ -1173,21 +1171,19 @@ void CCD::processBLOB(IBLOB* bp)
     strncpy(BLOBFilename, filename.toLatin1(), MAXINDIFILENAME);
     bp->aux2 = BLOBFilename;
 
-    if ((targetChip->isBatchMode() && targetChip->getCaptureMode() == FITS_NORMAL) || Options::showFITS() == false)
+    if (targetChip->getCaptureMode() == FITS_NORMAL && targetChip->isBatchMode() == true)
         KStars::Instance()->statusBar()->showMessage( i18n("%1 file saved to %2", QString(fmt).toUpper(), filename ), 0);
 
     KNotification::event( QLatin1String( "FITSReceived" ) , i18n("FITS file is received"));
 
-    if (targetChip->showFITS() == false && targetChip->getCaptureMode() == FITS_NORMAL)
+    /*if (targetChip->showFITS() == false && targetChip->getCaptureMode() == FITS_NORMAL)
     {
         emit BLOBUpdated(bp);
         return;
-    }
+    }*/
 
     if (BType == BLOB_IMAGE || BType == BLOB_CR2)
     {
-
-
         if (BType == BLOB_CR2)
         {
             if (QStandardPaths::findExecutable("dcraw").isEmpty() == false && QStandardPaths::findExecutable("cjpeg").isEmpty() == false)
@@ -1218,19 +1214,21 @@ void CCD::processBLOB(IBLOB* bp)
         QUrl url = QUrl::fromLocalFile(filename);
         ImageViewer *iv = new ImageViewer(url, QString(), KStars::Instance());
         if (iv)
+        {
            iv->show();
+           QFile::remove(filename);
+        }
     }
     // Unless we have cfitsio, we're done.
     #ifdef HAVE_CFITSIO
-    if (BType == BLOB_FITS && Options::showFITS() && (targetChip->showFITS() || targetChip->getCaptureMode() != FITS_NORMAL)
-            && targetChip->getCaptureMode() != FITS_WCSM)
+    if (BType == BLOB_FITS && targetChip->getCaptureMode() != FITS_WCSM)
     {
         QUrl fileURL(filename);
 
         if (fv == NULL)
         {
-            if (Options::singleWindowFITS())
-                fv = GUIManager::Instance()->getGenericFITSViewer();
+            if (Options::singleWindowCapturedFITS())
+                fv = KStars::Instance()->genericFITSViewer();
             else
                 fv = new FITSViewer(KStars::Instance());
 
@@ -1245,7 +1243,7 @@ void CCD::processBLOB(IBLOB* bp)
         bool preview = !targetChip->isBatchMode() && Options::singlePreviewFITS();
         if (preview)
         {
-            if (Options::singleWindowFITS())
+            if (Options::singleWindowCapturedFITS())
                 previewTitle = i18n("%1 Preview", getDeviceName());
             else
                 previewTitle = i18n("Preview");
@@ -1258,36 +1256,62 @@ void CCD::processBLOB(IBLOB* bp)
                 if (normalTabID == -1 || Options::singlePreviewFITS() == false)
                     normalTabID = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, previewTitle);
                 else if (fv->updateFITS(&fileURL, normalTabID, captureFilter) == false)
+                {
+                    fv->removeFITS(normalTabID);
                     normalTabID = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, previewTitle);
+                }
 
-                targetChip->setImage(fv->getView(normalTabID), FITS_NORMAL);
+                if (normalTabID >= 0)
+                    targetChip->setImage(fv->getView(normalTabID), FITS_NORMAL);
+                else
+                    // If opening file fails, we treat it the same as exposure failure and recapture again if possible
+                    emit newExposureValue(targetChip, 0, IPS_ALERT);
                 break;
 
             case FITS_FOCUS:
                 if (focusTabID == -1)
                     focusTabID = fv->addFITS(&fileURL, FITS_FOCUS, captureFilter);
                 else if (fv->updateFITS(&fileURL, focusTabID, captureFilter) == false)
+                {
+                    fv->removeFITS(focusTabID);
                     focusTabID = fv->addFITS(&fileURL, FITS_FOCUS, captureFilter);
+                }
 
-                targetChip->setImage(fv->getView(focusTabID), FITS_FOCUS);
+                if (focusTabID >= 0)
+                    targetChip->setImage(fv->getView(focusTabID), FITS_FOCUS);
+                else
+                    emit newExposureValue(targetChip, 0, IPS_ALERT);
                 break;
 
         case FITS_GUIDE:
             if (guideTabID == -1)
                 guideTabID = fv->addFITS(&fileURL, FITS_GUIDE, captureFilter);
             else if (fv->updateFITS(&fileURL, guideTabID, captureFilter) == false)
+            {
+                fv->removeFITS(guideTabID);
                 guideTabID = fv->addFITS(&fileURL, FITS_GUIDE, captureFilter);
+            }
 
-            targetChip->setImage(fv->getView(guideTabID), FITS_GUIDE);
+            if (guideTabID >= 0)
+                targetChip->setImage(fv->getView(guideTabID), FITS_GUIDE);
+            else
+                emit newExposureValue(targetChip, 0, IPS_ALERT);
             break;
 
         case FITS_CALIBRATE:
             if (calibrationTabID == -1)
                 calibrationTabID = fv->addFITS(&fileURL, FITS_CALIBRATE, captureFilter);
             else if (fv->updateFITS(&fileURL, calibrationTabID, captureFilter) == false)
+            {
+                fv->removeFITS(calibrationTabID);
                 calibrationTabID = fv->addFITS(&fileURL, FITS_CALIBRATE, captureFilter);
+            }
 
-            targetChip->setImage(fv->getView(calibrationTabID), FITS_CALIBRATE);
+            if (calibrationTabID >= 0)
+                targetChip->setImage(fv->getView(calibrationTabID), FITS_CALIBRATE);
+            else
+
+                emit newExposureValue(targetChip, 0, IPS_ALERT);
             break;
 
 
