@@ -31,6 +31,7 @@
 #include "kstarsdata.h"
 #include "Options.h"
 #include "skymap.h"
+#include "ksutils.h"
 
 // DEBUG EDIT. Uncomment for testing Proper Motion
 //#include "skycomponents/skymesh.h"
@@ -245,7 +246,7 @@ void StarObject::initPopupMenu( KSPopupMenu *pmenu ) {
     pmenu->createStarMenu( this );
 }
 
-void StarObject::updateCoords( KSNumbers *num, bool , const dms*, const dms*, bool ) {
+void StarObject::updateCoords( const KSNumbers *num, bool , const dms*, const dms*, bool ) {
     //Correct for proper motion of stars.  Determine RA and Dec offsets.
     //Proper motion is given im milliarcsec per year by the pmRA() and pmDec() functions.
     //That is numerically identical to the number of arcsec per millenium, so multiply by
@@ -269,7 +270,7 @@ void StarObject::updateCoords( KSNumbers *num, bool , const dms*, const dms*, bo
     setDec0( saveDec );
 }
 
-void StarObject::getIndexCoords( KSNumbers *num, double *ra, double *dec )
+void StarObject::getIndexCoords( const KSNumbers *num, double *ra, double *dec )
 {
     static double pmms;
 
@@ -397,96 +398,8 @@ QString StarObject::greekLetter( bool gchar ) const {
 
 QString StarObject::constell() const { // FIXME: Move this somewhere else, make this static, and give it a better name. Mostly for code cleanliness. Also, try to put it in a DB.
     QString code = name2().mid(4,3);
-    if ( code == "And" ) return QString("Andromedae");
-    if ( code == "Ant" ) return QString("Antliae");
-    if ( code == "Aps" ) return QString("Apodis");
-    if ( code == "Aqr" ) return QString("Aquarii");
-    if ( code == "Aql" ) return QString("Aquilae");
-    if ( code == "Ara" ) return QString("Arae");
-    if ( code == "Ari" ) return QString("Arietis");
-    if ( code == "Aur" ) return QString("Aurigae");
-    if ( code == "Boo" ) return QString("Bootis");
-    if ( code == "Cae" ) return QString("Caeli");
-    if ( code == "Cam" ) return QString("Camelopardalis");
-    if ( code == "Cnc" ) return QString("Cancri");
-    if ( code == "CVn" ) return QString("Canum Venaticorum");
-    if ( code == "CMa" ) return QString("Canis Majoris");
-    if ( code == "CMi" ) return QString("Canis Minoris");
-    if ( code == "Cap" ) return QString("Capricorni");
-    if ( code == "Car" ) return QString("Carinae");
-    if ( code == "Cas" ) return QString("Cassiopeiae");
-    if ( code == "Cen" ) return QString("Centauri");
-    if ( code == "Cep" ) return QString("Cephei");
-    if ( code == "Cet" ) return QString("Ceti");
-    if ( code == "Cha" ) return QString("Chamaeleontis");
-    if ( code == "Cir" ) return QString("Circini");
-    if ( code == "Col" ) return QString("Columbae");
-    if ( code == "Com" ) return QString("Comae Berenices");
-    if ( code == "CrA" ) return QString("Coronae Austrinae");
-    if ( code == "CrB" ) return QString("Coronae Borealis");
-    if ( code == "Crv" ) return QString("Corvi");
-    if ( code == "Crt" ) return QString("Crateris");
-    if ( code == "Cru" ) return QString("Crucis");
-    if ( code == "Cyg" ) return QString("Cygni");
-    if ( code == "Del" ) return QString("Delphini");
-    if ( code == "Dor" ) return QString("Doradus");
-    if ( code == "Dra" ) return QString("Draconis");
-    if ( code == "Equ" ) return QString("Equulei");
-    if ( code == "Eri" ) return QString("Eridani");
-    if ( code == "For" ) return QString("Fornacis");
-    if ( code == "Gem" ) return QString("Geminorum");
-    if ( code == "Gru" ) return QString("Gruis");
-    if ( code == "Her" ) return QString("Herculis");
-    if ( code == "Hor" ) return QString("Horologii");
-    if ( code == "Hya" ) return QString("Hydrae");
-    if ( code == "Hyi" ) return QString("Hydri");
-    if ( code == "Ind" ) return QString("Indi");
-    if ( code == "Lac" ) return QString("Lacertae");
-    if ( code == "Leo" ) return QString("Leonis");
-    if ( code == "LMi" ) return QString("Leonis Minoris");
-    if ( code == "Lep" ) return QString("Leporis");
-    if ( code == "Lib" ) return QString("Librae");
-    if ( code == "Lup" ) return QString("Lupi");
-    if ( code == "Lyn" ) return QString("Lyncis");
-    if ( code == "Lyr" ) return QString("Lyrae");
-    if ( code == "Men" ) return QString("Mensae");
-    if ( code == "Mic" ) return QString("Microscopii");
-    if ( code == "Mon" ) return QString("Monocerotis");
-    if ( code == "Mus" ) return QString("Muscae");
-    if ( code == "Nor" ) return QString("Normae");
-    if ( code == "Oct" ) return QString("Octantis");
-    if ( code == "Oph" ) return QString("Ophiuchi");
-    if ( code == "Ori" ) return QString("Orionis");
-    if ( code == "Pav" ) return QString("Pavonis");
-    if ( code == "Peg" ) return QString("Pegasi");
-    if ( code == "Per" ) return QString("Persei");
-    if ( code == "Phe" ) return QString("Phoenicis");
-    if ( code == "Pic" ) return QString("Pictoris");
-    if ( code == "Psc" ) return QString("Piscium");
-    if ( code == "PsA" ) return QString("Piscis Austrini");
-    if ( code == "Pup" ) return QString("Puppis");
-    if ( code == "Pyx" ) return QString("Pyxidis");
-    if ( code == "Ret" ) return QString("Reticuli");
-    if ( code == "Sge" ) return QString("Sagittae");
-    if ( code == "Sgr" ) return QString("Sagittarii");
-    if ( code == "Sco" ) return QString("Scorpii");
-    if ( code == "Scl" ) return QString("Sculptoris");
-    if ( code == "Sct" ) return QString("Scuti");
-    if ( code == "Ser" ) return QString("Serpentis");
-    if ( code == "Sex" ) return QString("Sextantis");
-    if ( code == "Tau" ) return QString("Tauri");
-    if ( code == "Tel" ) return QString("Telescopii");
-    if ( code == "Tri" ) return QString("Trianguli");
-    if ( code == "TrA" ) return QString("Trianguli Australis");
-    if ( code == "Tuc" ) return QString("Tucanae");
-    if ( code == "UMa" ) return QString("Ursae Majoris");
-    if ( code == "UMi" ) return QString("Ursae Minoris");
-    if ( code == "Vel" ) return QString("Velorum");
-    if ( code == "Vir" ) return QString("Virginis");
-    if ( code == "Vol" ) return QString("Volantis");
-    if ( code == "Vul" ) return QString("Vulpeculae");
 
-    return QString();
+    return KSUtils::constGenetiveFromAbbrev( code );
 }
 
 // The two routines below seem overly complicated but at least they are doing
